@@ -19,6 +19,7 @@
 #ifdef SW_USE_HTTP2
 
 #include "swoole_static_handler.h"
+#include "swoole_util.h"
 
 #include "main/php_variables.h"
 
@@ -47,7 +48,11 @@ Http2Stream::Stream(Http2Session *client, uint32_t _id) {
     ctx->keepalive = true;
     id = _id;
     local_window_size = SW_HTTP2_DEFAULT_WINDOW_SIZE;
-    remote_window_size = SW_HTTP2_DEFAULT_WINDOW_SIZE;
+    if(client->remote_settings.window_size > 0) {
+        remote_window_size = client->remote_settings.window_size;
+    } else {
+        remote_window_size = SW_HTTP2_DEFAULT_WINDOW_SIZE;
+    }
 }
 
 Http2Stream::~Stream() {
@@ -74,6 +79,25 @@ Http2Session::Session(SessionId _fd) {
     http2_sessions[_fd] = this;
 }
 
+void Http2Session::apply_setting(Server *serv) {
+    Http2::Settings *settings = &local_settings;
+    if(serv->http2_header_table_size > 0) {
+        local_settings.header_table_size = serv->http2_header_table_size;
+    }
+    if(serv->http2_initial_window_size > 0) {
+        local_settings.window_size = serv->http2_initial_window_size;
+    }
+    if(serv->http2_max_concurrent_streams > 0) {
+        local_settings.max_concurrent_streams = serv->http2_max_concurrent_streams;
+    }
+    if(serv->http2_max_frame_size > 0) {
+        local_settings.max_frame_size = serv->http2_max_frame_size;
+    }
+    if(serv->http2_max_header_list_size > 0) {
+        local_settings.max_header_list_size = serv->http2_max_header_list_size;
+    }
+}
+
 Http2Session::~Session() {
     for (auto iter = streams.begin(); iter != streams.end(); iter++) {
         delete iter->second;
@@ -166,6 +190,18 @@ static bool swoole_http2_is_static_file(Server *serv, HttpContext *ctx) {
             return true;
         }
 
+        std::set<std::string> dir_files;
+        std::string index_file = "";
+        if (serv->http_index_files && !serv->http_index_files->empty() && handler.is_dir()) {
+            handler.get_dir_files(dir_files);
+            index_file = swoole::intersection(*serv->http_index_files, dir_files);
+            if (index_file != "" && !handler.set_filename(index_file)) {
+                return false;
+            } else if (index_file == "" && !serv->http_autoindex) {
+                return false;
+            }
+        }
+
         auto date_str = handler.get_date();
         auto date_str_last_modified = handler.get_date_last_modified();
 
@@ -813,7 +849,7 @@ int swoole_http2_server_parse(Http2Session *client, const char *buf) {
     Http2Stream *stream = nullptr;
     int type = buf[3];
     int flags = buf[4];
-    int retval = SW_ERR;
+    int retval = SW_OK;
     uint32_t stream_id = ntohl((*(int *) (buf + 5))) & 0x7fffffff;
 
     if (stream_id > client->last_stream_id) {
@@ -1053,6 +1089,7 @@ int swoole_http2_server_onFrame(Server *serv, Connection *conn, RecvData *req) {
     Http2Session *client = http2_sessions[session_id];
     if (client == nullptr) {
         client = new Http2Session(session_id);
+        client->apply_setting(serv);
     }
 
     client->handle = swoole_http2_onRequest;
@@ -1069,6 +1106,9 @@ int swoole_http2_server_onFrame(Server *serv, Connection *conn, RecvData *req) {
     zval zdata;
     php_swoole_get_recv_data(serv, &zdata, req);
     int retval = swoole_http2_server_parse(client, Z_STRVAL(zdata));
+    if(retval != SW_OK) {
+        client->default_ctx->close(client->default_ctx);
+    }
     zval_ptr_dtor(&zdata);
 
     return retval;
