@@ -1747,6 +1747,18 @@ static PHP_FUNCTION(swoole_stream_select) {
     Z_PARAM_LONG(usec)
     ZEND_PARSE_PARAMETERS_END_EX(RETURN_FALSE);
 
+    double timeout = -1;
+    if (!secnull) {
+        if (sec < 0) {
+            php_error_docref(nullptr, E_WARNING, "The seconds parameter must be greater than 0");
+            RETURN_FALSE;
+        } else if (usec < 0) {
+            php_error_docref(nullptr, E_WARNING, "The microseconds parameter must be greater than 0");
+            RETURN_FALSE;
+        }
+        timeout = (double) sec + ((double) usec / 1000000);
+    }
+
     std::unordered_map<int, PollSocket> fds;
 
     if (r_array != nullptr) {
@@ -1766,18 +1778,6 @@ static PHP_FUNCTION(swoole_stream_select) {
         RETURN_FALSE;
     }
 
-    double timeout = -1;
-    if (!secnull) {
-        if (sec < 0) {
-            php_error_docref(nullptr, E_WARNING, "The seconds parameter must be greater than 0");
-            RETURN_FALSE;
-        } else if (usec < 0) {
-            php_error_docref(nullptr, E_WARNING, "The microseconds parameter must be greater than 0");
-            RETURN_FALSE;
-        }
-        timeout = (double) sec + ((double) usec / 1000000);
-    }
-
     /* slight hack to support buffered data; if there is data sitting in the
      * read buffer of any of the streams in the read array, let's pretend
      * that we selected, but return only the readable sockets */
@@ -1790,6 +1790,10 @@ static PHP_FUNCTION(swoole_stream_select) {
             if (e_array != nullptr) {
                 zend_hash_clean(Z_ARRVAL_P(e_array));
             }
+            for (auto &i : fds) {
+                zend::KeyValue *kv = (zend::KeyValue *) i.second.ptr;
+                delete kv;
+            }
             RETURN_LONG(retval);
         }
     }
@@ -1808,6 +1812,10 @@ static PHP_FUNCTION(swoole_stream_select) {
      * timeout or add failed
      */
     if (!System::socket_poll(fds, timeout)) {
+        for (auto &i : fds) {
+            zend::KeyValue *kv = (zend::KeyValue *) i.second.ptr;
+            delete kv;
+        }
         RETURN_LONG(0);
     }
 
