@@ -14,19 +14,14 @@
 
 #define SWOOLE_MAJOR_VERSION 4
 #define SWOOLE_MINOR_VERSION 11
-#define SWOOLE_RELEASE_VERSION 0
+#define SWOOLE_RELEASE_VERSION 1
 #define SWOOLE_EXTRA_VERSION ""
-#define SWOOLE_VERSION "4.11.0"
-#define SWOOLE_VERSION_ID 41100
+#define SWOOLE_VERSION "4.11.1"
+#define SWOOLE_VERSION_ID 41101
 #define SWOOLE_API_VERSION_ID 0x202012a
 
 #define SWOOLE_BUG_REPORT                                                                                              \
     "A bug occurred in OpenSwoole-v" SWOOLE_VERSION ", please report it.\n"                                            \
-    "The Swoole developers probably don't know about it,\n"                                                            \
-    "and unless you report it, chances are it won't be fixed.\n"                                                       \
-    "You can read How to report a bug doc before submitting any bug reports:\n"                                        \
-    ">> https://github.com/openswoole/swoole-src/blob/master/.github/ISSUE.md \n"                                      \
-    "Please do not send bug reports in the mailing list or personal letters.\n"                                        \
-    "The issue page is also suitable to submit feature requests.\n"
-
+    "Please submit bug report at:\n"                                                                                   \
+    ">> https://github.com/openswoole/swoole-src/issues \n"
 #endif
